pub struct DaemonSetCondition {
pub last_transition_time: Option<Time>,
pub message: Option<String>,
pub reason: Option<String>,
pub status: String,
pub type_: String,
}Expand description
DaemonSetCondition describes the state of a DaemonSet at a certain point.
Fields
last_transition_time: Option<Time>Last time the condition transitioned from one status to another.
message: Option<String>A human readable message indicating details about the transition.
reason: Option<String>The reason for the condition’s last transition.
status: StringStatus of the condition, one of True, False, Unknown.
type_: StringType of DaemonSet condition.