Struct k8s_openapi::api::certificates::v1::CertificateSigningRequest
source · [−]pub struct CertificateSigningRequest {
pub metadata: ObjectMeta,
pub spec: CertificateSigningRequestSpec,
pub status: Option<CertificateSigningRequestStatus>,
}Expand description
CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.
Kubelets use this API to obtain:
- client certificates to authenticate to kube-apiserver (with the “kubernetes.io/kube-apiserver-client-kubelet” signerName).
- serving certificates for TLS endpoints kube-apiserver can connect to securely (with the “kubernetes.io/kubelet-serving” signerName).
This API can be used to request client certificates to authenticate to kube-apiserver (with the “kubernetes.io/kube-apiserver-client” signerName), or to obtain certificates from custom non-Kubernetes signers.
Fields
metadata: ObjectMetaspec: CertificateSigningRequestSpecspec contains the certificate request, and is immutable after creation. Only the request, signerName, expirationSeconds, and usages fields can be set on creation. Other fields are derived by Kubernetes and cannot be modified by users.
status: Option<CertificateSigningRequestStatus>status contains information about whether the request is approved or denied, and the certificate issued by the signer, or the failure condition indicating signer failure.
Implementations
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn create(
body: &CertificateSigningRequest,
optional: CreateOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
pub fn create(
body: &CertificateSigningRequest,
optional: CreateOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
create a CertificateSigningRequest
Use the returned crate::ResponseBody<crate::CreateResponse<Self>> constructor, or crate::CreateResponse<Self> directly, to parse the HTTP response.
Arguments
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn delete(
name: &str,
optional: DeleteOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
pub fn delete(
name: &str,
optional: DeleteOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
delete a CertificateSigningRequest
Use the returned crate::ResponseBody<crate::DeleteResponse<Self>> constructor, or crate::DeleteResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
-
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn delete_collection(
delete_optional: DeleteOptional<'_>,
list_optional: ListOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
pub fn delete_collection(
delete_optional: DeleteOptional<'_>,
list_optional: ListOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
delete collection of CertificateSigningRequest
Use the returned crate::ResponseBody<crate::DeleteResponse<crate::List<Self>>> constructor, or crate::DeleteResponse<crate::List<Self>> directly, to parse the HTTP response.
Arguments
-
delete_optionalDelete options. Use
Default::default()to not pass any. -
list_optionalList options. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn list(
optional: ListOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list(
optional: ListOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind CertificateSigningRequest
This operation only supports listing all items of this type.
Use the returned crate::ResponseBody<crate::ListResponse<Self>> constructor, or crate::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn patch(
name: &str,
body: &Patch,
optional: PatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch(
name: &str,
body: &Patch,
optional: PatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update the specified CertificateSigningRequest
Use the returned crate::ResponseBody<crate::PatchResponse<Self>> constructor, or crate::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn patch_approval(
name: &str,
body: &Patch,
optional: PatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_approval(
name: &str,
body: &Patch,
optional: PatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update approval of the specified CertificateSigningRequest
Use the returned crate::ResponseBody<crate::PatchResponse<Self>> constructor, or crate::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn patch_status(
name: &str,
body: &Patch,
optional: PatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_status(
name: &str,
body: &Patch,
optional: PatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update status of the specified CertificateSigningRequest
Use the returned crate::ResponseBody<crate::PatchResponse<Self>> constructor, or crate::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn read(
name: &str
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReadCertificateSigningRequestResponse>), RequestError>
pub fn read(
name: &str
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReadCertificateSigningRequestResponse>), RequestError>
read the specified CertificateSigningRequest
Use the returned crate::ResponseBody<ReadCertificateSigningRequestResponse> constructor, or ReadCertificateSigningRequestResponse directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn read_approval(
name: &str
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReadCertificateSigningRequestApprovalResponse>), RequestError>
pub fn read_approval(
name: &str
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReadCertificateSigningRequestApprovalResponse>), RequestError>
read approval of the specified CertificateSigningRequest
Use the returned crate::ResponseBody<ReadCertificateSigningRequestApprovalResponse> constructor, or ReadCertificateSigningRequestApprovalResponse directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn read_status(
name: &str
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReadCertificateSigningRequestStatusResponse>), RequestError>
pub fn read_status(
name: &str
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReadCertificateSigningRequestStatusResponse>), RequestError>
read status of the specified CertificateSigningRequest
Use the returned crate::ResponseBody<ReadCertificateSigningRequestStatusResponse> constructor, or ReadCertificateSigningRequestStatusResponse directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn replace(
name: &str,
body: &CertificateSigningRequest,
optional: ReplaceOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace(
name: &str,
body: &CertificateSigningRequest,
optional: ReplaceOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace the specified CertificateSigningRequest
Use the returned crate::ResponseBody<crate::ReplaceResponse<Self>> constructor, or crate::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn replace_approval(
name: &str,
body: &CertificateSigningRequest,
optional: ReplaceOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_approval(
name: &str,
body: &CertificateSigningRequest,
optional: ReplaceOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace approval of the specified CertificateSigningRequest
Use the returned crate::ResponseBody<crate::ReplaceResponse<Self>> constructor, or crate::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn replace_status(
name: &str,
body: &CertificateSigningRequest,
optional: ReplaceOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_status(
name: &str,
body: &CertificateSigningRequest,
optional: ReplaceOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace status of the specified CertificateSigningRequest
Use the returned crate::ResponseBody<crate::ReplaceResponse<Self>> constructor, or crate::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the CertificateSigningRequest
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
sourceimpl CertificateSigningRequest
impl CertificateSigningRequest
sourcepub fn watch(
optional: WatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch(
optional: WatchOptional<'_>
) -> Result<(Request<Vec<u8>>, fn(_: StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind CertificateSigningRequest
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned crate::ResponseBody<crate::WatchResponse<Self>> constructor, or crate::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.