[−][src]Struct k8s_openapi::api::certificates::v1beta1::PatchCertificateSigningRequestStatusOptional
Optional parameters of CertificateSigningRequest::patch_certificate_signing_request_status
Fields
dry_run: Option<&'a str>When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed
pretty: Option<&'a str>If 'true', then the output is pretty printed.