pub struct EnvVarSource {
pub config_map_key_ref: Option<ConfigMapKeySelector>,
pub field_ref: Option<ObjectFieldSelector>,
pub resource_field_ref: Option<ResourceFieldSelector>,
pub secret_key_ref: Option<SecretKeySelector>,
}Expand description
EnvVarSource represents a source for the value of an EnvVar.
Fields
config_map_key_ref: Option<ConfigMapKeySelector>Selects a key of a ConfigMap.
field_ref: Option<ObjectFieldSelector>Selects a field of the pod: supports metadata.name, metadata.namespace, metadata.labels\['\<KEY\>'\], metadata.annotations\['\<KEY\>'\], spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs.
resource_field_ref: Option<ResourceFieldSelector>Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, limits.ephemeral-storage, requests.cpu, requests.memory and requests.ephemeral-storage) are currently supported.
secret_key_ref: Option<SecretKeySelector>Selects a key of a secret in the pod’s namespace