pub struct PodSchedulingGate {
pub name: String,
}Expand description
PodSchedulingGate is associated to a Pod to guard its scheduling.
Fields
name: StringName of the scheduling gate. Each scheduling gate must have a unique name field.