pub struct ScaleIOPersistentVolumeSource {
pub fs_type: Option<String>,
pub gateway: String,
pub protection_domain: Option<String>,
pub read_only: Option<bool>,
pub secret_ref: SecretReference,
pub ssl_enabled: Option<bool>,
pub storage_mode: Option<String>,
pub storage_pool: Option<String>,
pub system: String,
pub volume_name: Option<String>,
}Expand description
ScaleIOPersistentVolumeSource represents a persistent ScaleIO volume
Fields
fs_type: Option<String>fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. “ext4”, “xfs”, “ntfs”. Default is “xfs”
gateway: Stringgateway is the host address of the ScaleIO API Gateway.
protection_domain: Option<String>protectionDomain is the name of the ScaleIO Protection Domain for the configured storage.
read_only: Option<bool>readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
secret_ref: SecretReferencesecretRef references to the secret for ScaleIO user and other sensitive information. If this is not provided, Login operation will fail.
ssl_enabled: Option<bool>sslEnabled is the flag to enable/disable SSL communication with Gateway, default false
storage_mode: Option<String>storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned.
storage_pool: Option<String>storagePool is the ScaleIO Storage Pool associated with the protection domain.
system: Stringsystem is the name of the storage system as configured in ScaleIO.
volume_name: Option<String>volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source.