pub struct ScopedResourceSelectorRequirement {
pub operator: String,
pub scope_name: String,
pub values: Option<Vec<String>>,
}Expand description
A scoped-resource selector requirement is a selector that contains values, a scope name, and an operator that relates the scope name and values.
Fields
operator: StringRepresents a scope’s relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist.
scope_name: StringThe name of the scope that the selector applies to.
values: Option<Vec<String>>An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.