pub struct Taint {
pub effect: String,
pub key: String,
pub time_added: Option<Time>,
pub value: Option<String>,
}Expand description
The node this Taint is attached to has the “effect” on any pod that does not tolerate the Taint.
Fields
effect: StringRequired. The effect of the taint on pods that do not tolerate the taint. Valid effects are NoSchedule, PreferNoSchedule and NoExecute.
key: StringRequired. The taint key to be applied to a node.
time_added: Option<Time>TimeAdded represents the time at which the taint was added. It is only written for NoExecute taints.
value: Option<String>The taint value corresponding to the taint key.