pub struct ResourcePoolStatusRequestStatus {
pub conditions: Option<Vec<Condition>>,
pub pool_count: i32,
pub pools: Option<Vec<PoolStatus>>,
}Expand description
ResourcePoolStatusRequestStatus contains the calculated pool status information.
Fields
conditions: Option<Vec<Condition>>Conditions provide information about the state of the request. A condition with type=Complete or type=Failed will always be set when the status is populated.
Known condition types: - “Complete”: True when the request has been processed successfully - “Failed”: True when the request could not be processed
pool_count: i32PoolCount is the total number of pools that matched the filter criteria, regardless of truncation. This helps users understand how many pools exist even when the response is truncated. A value of 0 means no pools matched the filter criteria.
pools: Option<Vec<PoolStatus>>Pools contains the first spec.limit matching pools, sorted by driver then pool name. If len(pools) \< poolCount, the list was truncated. When omitted, no pools matched the request filters.