pub struct VolumeAttachmentStatus {
pub attach_error: Option<VolumeError>,
pub attached: bool,
pub attachment_metadata: Option<BTreeMap<String, String>>,
pub detach_error: Option<VolumeError>,
}Expand description
VolumeAttachmentStatus is the status of a VolumeAttachment request.
Fields
attach_error: Option<VolumeError>attachError represents the last error encountered during attach operation, if any. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
attached: boolattached indicates the volume is successfully attached. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
attachment_metadata: Option<BTreeMap<String, String>>attachmentMetadata is populated with any information returned by the attach operation, upon successful attach, that must be passed into subsequent WaitForAttach or Mount calls. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.
detach_error: Option<VolumeError>detachError represents the last error encountered during detach operation, if any. This field must only be set by the entity completing the detach operation, i.e. the external-attacher.