pub trait Metadata: Resource {
type Ty;
// Required methods
fn metadata(&self) -> &<Self as Metadata>::Ty;
fn metadata_mut(&mut self) -> &mut <Self as Metadata>::Ty;
}Expand description
A trait applied to all Kubernetes resources that have metadata.
Required Associated Types
Required Methods
Sourcefn metadata(&self) -> &<Self as Metadata>::Ty
fn metadata(&self) -> &<Self as Metadata>::Ty
Gets a reference to the metadata of this resource value.
Sourcefn metadata_mut(&mut self) -> &mut <Self as Metadata>::Ty
fn metadata_mut(&mut self) -> &mut <Self as Metadata>::Ty
Gets a mutable reference to the metadata of this resource value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".